@@ -12,15 +12,18 @@ Lugh - Pure C LLM Inference Engine for Perl (built on ggml)
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 require XSLoader;
 XSLoader::load('Lugh', $VERSION);
 
+# Load Perl extensions for XS packages
+require Lugh::Inference;
+
 =head1 SYNOPSIS
 
     use Lugh;
@@ -40,7 +43,7 @@ XSLoader::load('Lugh', $VERSION);
     my @tokens = $tokenizer->encode("The capital of France is");
     
     # Run forward pass to get logits
-    my @logits = $inference->forward(\@tokens);
+    my @logits = $inference->forward(tokens => \@tokens);
     
     # Find most likely next token (greedy decoding)
     my $max_idx = 0;
@@ -203,7 +206,7 @@ Lugh provides two levels of API:
     my @tokens = $tokenizer->encode("Once upon a time");
     
     for (1..50) {  # Generate 50 tokens
-        my @logits = $inference->forward(\@tokens);
+        my @logits = $inference->forward(tokens => \@tokens);
         
         # Sample next token (greedy)
         my $next = 0;
